package
Version:
v0.0.0-...-18bfe34
Opens a new window with list of versions in this module.
Published: Feb 25, 2021
License: LGPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
MachId uint16 `json:"mach_id"`
PhyFileConfigs []PhyFileConfig `json:"phyfiles"`
Volumes []interface{}
}
type PhyFileConfig struct {
VolId uint16 `json:"phyfile_id"`
Path string `json:"path"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.