package
Version:
v0.0.0-...-18bfe34
Opens a new window with list of versions in this module.
Published: Feb 25, 2021
License: LGPL-3.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Dbfile struct {
FileId string `mx.orm:"file_id"`
Metadata string `mx.orm:"metadata"`
Filecontent []byte `mx.orm:"filecontent"`
TimeCreated int64 `mx.orm:"time_created"`
TimeUpdated int64 `mx.orm:"time_updated"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.